it("should correctly pass complex query object with remaining request", function() {
	expect(require("./a")).toBe("ok");
});
